==> popup_message-6.x-1.0.tar.gz: popup_message/js/popup.js <==
/**
 * @file
 * jQuery code.
 * Based on code: Adrian "yEnS" Mato Gondelle, twitter: @adrianmg
 * Modifications for Drupal: Grzegorz Bartman grzegorz.bartman@openbit.pl
 */


// Setting up popup.
// 0 means disabled; 1 means enabled.
var popupStatus = 0;

/**
 * Loading popup with jQuery.
 */
function loadPopup() {
  // Loads popup only if it is disabled.
  if (popupStatus == 0) {
    $("#backgroundPopup").css( {
      "opacity": "0.7"
    });
    $("#backgroundPopup").fadeIn("slow");
    $("#popupContact").fadeIn("slow");
    popupStatus = 1;
  }
}

/**
 * Disabling popup with jQuery.
 */
function disablePopup() {
  // Disables popup only if it is enabled.
  if (popupStatus == 1) {
    $("#backgroundPopup").fadeOut("slow");
    $("#popupContact").fadeOut("slow");
    popupStatus = 0;
  }
}

/**
 * Centering popup.
 */
function centerPopup() {
  // Request data for centering.
  var windowWidth = document.documentElement.clientWidth;
  var windowHeight = document.documentElement.clientHeight;
  var popupHeight = $("#popupContact").height();
  var popupWidth = $("#popupContact").width();
  // Centering.
  $("#popupContact").css( {
    "position": "absolute",
    "top": windowHeight / 2 - popupHeight / 2,
    "left": windowWidth / 2 - popupWidth / 2
  });
  // Only need force for IE6.
  $("#backgroundPopup").css( {
    "height": windowHeight
  });

}

Drupal.behaviors.anonymousMessage = function (context) {
  // Add message.
  var popupTitle = Drupal.settings.popup_message.title;
  var popupBody = Drupal.settings.popup_message.body;
  $('#container').append('<div id="popupContact"><a id="popupContactClose">x</a>\n\
    <h1>' + popupTitle + '</h1><p id="contactArea">' + popupBody
    + '</div><div id="backgroundPopup"></div>');

  // Loading popup.
  centerPopup();
  loadPopup();

  // Closing popup.
  // Click the x event!
  $("#popupContactClose").click(function() {
    disablePopup();
  });
  // Click out event!
  $("#backgroundPopup").click(function() {
    disablePopup();
  });
  // Press Escape event!
  $(document).keypress(function(e) {
    if (e.keyCode == 27 && popupStatus == 1) {
      disablePopup();
    }
  });

};

==> popup_message-6.x-1.1.tar.gz: popup_message/js/popup.js <==
/**
 * @file
 * jQuery code.
 * Based on code: Adrian "yEnS" Mato Gondelle, twitter: @adrianmg
 * Modifications for Drupal: Grzegorz Bartman grzegorz.bartman@openbit.pl
 */


// Setting up popup.
// 0 means disabled; 1 means enabled.
var popupStatus = 0;

/**
 * Loading popup with jQuery.
 */
function loadPopup() {
  // Loads popup only if it is disabled.
  if (popupStatus == 0) {
    $("#backgroundPopup").css( {
      "opacity": "0.7"
    });
    $("#backgroundPopup").fadeIn("slow");
    $("#popupContact").fadeIn("slow");
    popupStatus = 1;
  }
}

/**
 * Disabling popup with jQuery.
 */
function disablePopup() {
  // Disables popup only if it is enabled.
  if (popupStatus == 1) {
    $("#backgroundPopup").fadeOut("slow");
    $("#popupContact").fadeOut("slow");
    popupStatus = 0;
  }
}

/**
 * Centering popup.
 */
function centerPopup() {
  // Request data for centering.
  var windowWidth = document.documentElement.clientWidth;
  var windowHeight = document.documentElement.clientHeight;
  var popupHeight = $("#popupContact").height();
  var popupWidth = $("#popupContact").width();
  // Centering.
  $("#popupContact").css( {
    "position": "absolute",
    "top": windowHeight / 2 - popupHeight / 2,
    "left": windowWidth / 2 - popupWidth / 2
  });
  // Only need force for IE6.
  $("#backgroundPopup").css( {
    "height": windowHeight
  });

}

Drupal.behaviors.anonymousMessage = function (context) {
  
  var popup_message_cookie = $.cookie("popup_message_displayed");  
  if(popup_message_cookie != 1) {
    // Set cookie.
    $.cookie("popup_message_displayed", 1, { path: '/' });

    // Add message.
    var popupTitle = Drupal.settings.popup_message.title;
    var popupBody = Drupal.settings.popup_message.body;    
    $('body').append('<div id="popupContact"><a id="popupContactClose">x</a>\n\
    <h1>' + popupTitle + '</h1><p id="contactArea">' + popupBody
      + '</div><div id="backgroundPopup"></div>');

    // Loading popup.
    centerPopup();
    loadPopup();

    // Closing popup.
    // Click the x event!
    $("#popupContactClose").click(function() {
      disablePopup();
    });
    // Click out event!
    $("#backgroundPopup").click(function() {
      disablePopup();
    });
    // Press Escape event!
    $(document).keypress(function(e) {
      if (e.keyCode == 27 && popupStatus == 1) {
        disablePopup();
      }
    });
  }
};
